@@ -1,18 +1,46 @@
-import aiosqlite
 from ast import literal_eval
+import aiosqlite
 
 
-class Connect:
+class SQLCommands(object):
+    def __init__(self, database_name: str, table_name: str, id_column: str):
+        self._database_name = database_name
+        self._table_name = table_name
+        self._id_column = id_column
+
+    async def delete(self, row_id):
+        """
+        deletes a certain row from the table.
+        :param row_id: The id of the row.
+        :type row_id: int
+        """
+        async with aiosqlite.connect(self._database_name) as db:
+            async with db.cursor() as cursor:
+                await cursor.execute(
+                    f"DELETE FROM {self._table_name} WHERE {self._id_column} = ?", (row_id, ))
+            await db.commit()
+
+    async def execute(self, query):
+        """
+        Execute SQL query.
+        """
+        async with aiosqlite.connect(self._database_name) as db:
+            async with db.cursor() as cursor:
+                cur = await cursor.execute(query)
+                res = await cur.fetchall()
+            await db.commit()
+            return res
+
+
+class Connect(SQLCommands):
     """
     Instantiate a conversion to and from sqlite3 database and python dictionary.
     """
 
     def __init__(self, database_name: str, table_name: str, id_column: str):
-        self.database_name = database_name
-        self.table_name = table_name
-        self.id_column = id_column
+        super().__init__(database_name, table_name, id_column)
 
-    async def to_dict(self, my_id, *column_names: str):
+    async def to_dict(self, my_id, *column_names: str) -> dict:
         """
         Convert a sqlite3 table into a python dictionary.
         :param my_id: The id of the row.
@@ -22,24 +50,23 @@ class Connect:
         :return: The dictionary.
         :rtype: dict
         """
-        async with aiosqlite.connect(self.database_name) as db:
+        async with aiosqlite.connect(self._database_name) as db:
             async with db.cursor() as cursor:
-
-                table_name = self.table_name.replace("'", "").replace('"', "")
                 data = {}
-                columns = str(column_names).replace("(", "").replace(
-                    ")", "").replace('"', "").replace("'", "")
-                columns = columns.replace(
-                    columns[-1], "") if columns.endswith(",") else columns
+                columns = ""
+                for column in column_names:
+                    columns += column + ", "
+                columns = columns[:-2]  # Remove the ", " at the end
 
                 if columns == "*":
                     getID = await cursor.execute(
-                        f"SELECT {columns} FROM {table_name} WHERE {self.id_column} = ?", (my_id,))
+                        f"SELECT {columns} FROM {self._table_name} WHERE {self._id_column} = ?", (my_id,))
                     fieldnames = [f[0] for f in getID.description]
                     values = await getID.fetchone()
                     values = list(values)
                     for v in range(len(values)):
                         if str(values[v]).startswith("[") or str(values[v]).startswith("{") or str(values[v]).startswith("("):
+                            values[v] = str(values[v])
                             try:
                                 values[v] = literal_eval(values[v])
                             except Exception as e:
@@ -51,11 +78,12 @@ class Connect:
                     return data
                 else:
                     getID = await cursor.execute(
-                        f"SELECT {columns} FROM {table_name} WHERE {self.id_column} = ?", (my_id, ))
+                        f"SELECT {columns} FROM {self._table_name} WHERE {self._id_column} = ?", (my_id,))
                     values = await getID.fetchone()
                     values = list(values)
                     for v in range(len(values)):
                         if str(values[v]).startswith("[") or str(values[v]).startswith("{") or str(values[v]).startswith("("):
+                            values[v] = str(values[v])
                             try:
                                 values[v] = literal_eval(values[v])
                             except Exception as e:
@@ -78,10 +106,10 @@ class Connect:
         :return: The SQLite3 Table.
         :rtype: sqlite
         """
-        async with aiosqlite.connect(self.database_name) as db:
+        async with aiosqlite.connect(self._database_name) as db:
             async with db.cursor() as cursor:
-                table_name = self.table_name
-                getUser = await cursor.execute(f"SELECT {self.id_column} FROM {table_name} WHERE {self.id_column} = ?", (my_id, ))
+                getUser = await cursor.\
+                    execute(f"SELECT {self._id_column} FROM {self._table_name} WHERE {self._id_column} = ?", (my_id,))
                 isUserExists = await getUser.fetchone()
                 if isUserExists:
                     for key, val in dictionary.items():
@@ -89,20 +117,21 @@ class Connect:
                             val = str(val)
                         else:
                             pass
-                        await cursor.execute(f"UPDATE {table_name} SET {key} = ? WHERE {self.id_column} = ?", (val, my_id,))
+                        await cursor.execute(f"UPDATE {self._table_name} SET {key} = ? WHERE {self._id_column} = ?", (val, my_id,))
                 else:
-                    await cursor.execute(f"INSERT INTO {table_name} ({self.id_column}) VALUES ( ? )", (my_id, ))
+                    await cursor.execute(f"INSERT INTO {self._table_name} ({self._id_column}) VALUES ( ? )", (my_id,))
                     for key, val in dictionary.items():
                         if str(val).startswith("[") or str(val).startswith("{") or str(val).startswith("("):
                             val = str(val)
                         else:
                             pass
-                        await cursor.execute(f"UPDATE {table_name} SET {key} = ? WHERE {self.id_column} = ?", (val, my_id,))
+                        await cursor.execute(f"UPDATE {self._table_name} SET {key} = ? WHERE {self._id_column} = ?", (val, my_id,))
 
             await db.commit()
 
-    async def select(self, column_name: str, limit: int = None, order_by: str = None, ascending: bool = True
-                     , equal=None, like: str = None, between: tuple = None, distinct: bool = False, offset: int = None):
+    async def select(self, column_name: str, limit: int = None, order_by: str = None,
+                     ascending: bool = True, equal=None, like: str = None, between: tuple = None,
+                     distinct: bool = False, offset: int = None) -> list:
         """
         Select a column from the table.
 
@@ -126,40 +155,47 @@ class Connect:
         :return: The list.
         :rtype: list
         """
-        async with aiosqlite.connect(self.database_name) as db:
+        async with aiosqlite.connect(self._database_name) as db:
             async with db.cursor() as cursor:
 
-                query = f"SELECT {column_name} FROM {self.table_name}"
-                parameters = []
+                query = f"SELECT ? FROM ?"
+                parameters = [column_name.strip("'"), self._table_name.strip("'")]
                 condition = False
                 if distinct is True:
-                    query = f"SELECT DISTINCT {column_name} FROM {self.table_name}"
+                    query = f"SELECT DISTINCT ? FROM ?"
                 if equal is not None and condition is False:
                     condition = True
-                    query += f" WHERE {column_name} = ?"
-                    parameters.append(equal,)
+                    query += f" WHERE ? = ?"
+                    parameters.append(column_name.strip("'"))
+                    parameters.append(equal)
                 elif equal is not None and condition is True:
-                    query += f" AND {column_name} = ?"
+                    query += f" AND ? = ?"
+                    parameters.append(column_name.strip("'"))
                     parameters.append(equal)
                 if like is not None and condition is False:
                     condition = True
-                    query += f" WHERE {column_name} LIKE ?"
+                    query += f" WHERE ? LIKE ?"
+                    parameters.append(column_name.strip("'"))
                     parameters.append("%"+like+"%")
                 elif like is not None and condition is True:
-                    query += f" AND {column_name} LIKE ?"
+                    query += f" AND ? LIKE ?"
+                    parameters.append(column_name.strip("'"))
                     parameters.append("%"+like+"%")
                 if between is not None and condition is False:
                     condition = True
-                    query += f" WHERE {column_name} BETWEEN ? AND ?"
+                    query += f" WHERE ? BETWEEN ? AND ?"
+                    parameters.append(column_name.strip("'"))
                     parameters.append(range(between[0], between[1]).start)
                     parameters.append(range(between[0], between[1]).stop)
 
                 elif between is not None and condition is True:
-                    query += f" AND {column_name} BETWEEN ? AND ?"
+                    query += f" AND ? BETWEEN ? AND ?"
+                    parameters.append(column_name.strip("'"))
                     parameters.append(range(between[0], between[1]).start)
                     parameters.append(range(between[0], between[1]).stop)
                 if order_by is not None:
-                    query += f" ORDER BY {order_by}"
+                    query += f" ORDER BY ?"
+                    parameters.append(order_by.strip("'"))
                 if ascending is False:
                     query += f" DESC"
                 else:
@@ -173,10 +209,11 @@ class Connect:
                 elif offset is not None and limit is None:
                     raise Exception("You can't use kwarg 'offset' without kwarg 'limit'")
                 parameters = str(tuple(parameters))
-                parameters = eval(parameters)
-                # print(f"query ==> await cursor.execute(\"{query}\", {parameters})")
-                # print(parameters)
-                getValues = await cursor.execute(query, parameters)
+                parameters = parameters[:-1] + ",)"
+                parameters = literal_eval(parameters)
+                print(f"query ==> await cursor.execute(\"{query}\", {parameters})")
+                print(parameters)
+                getValues = await cursor.execute(query, literal_eval(parameters))
                 values = await getValues.fetchall()
                 my_list = []
 
@@ -207,26 +244,3 @@ class Connect:
                         my_list.append(i)
 
                 return my_list
-
-    async def delete(self, row_id):
-        """
-        deletes a certain row from the table.
-        :param row_id: The id of the row.
-        :type row_id: int
-        """
-        async with aiosqlite.connect(self.database_name) as db:
-            async with db.cursor() as cursor:
-                await cursor.execute(
-                    f"DELETE FROM {self.table_name} WHERE {self.id_column} = ?", (row_id, ))
-            await db.commit()
-
-    async def execute(self, query):
-        """
-        Execute SQL query.
-        """
-        async with aiosqlite.connect(self.database_name) as db:
-            async with db.cursor() as cursor:
-                cur = await cursor.execute(query)
-                res = await cur.fetchall()
-            await db.commit()
-            return res
